@@ -2,7 +2,7 @@
 from randname import randname
 
 def main():
-    return f"{randname.first_name()} {randname.last_name()}"
+    print(f"{randname.first_name()} {randname.last_name()}")
 
 if __name__ == "__main__":
-    print(main())
\ No newline at end of file
+    main()
\ No newline at end of file
